@@ -4,6 +4,8 @@
 """
 from toolz.itertoolz import pluck
 
+import numpy as np
+
 from .. decoder import Decoder
 
 ##############################
@@ -32,11 +34,13 @@ class BinaryToIntDecoder(Decoder):
         mapped to the first phenotypic value, and the last 3 bits making up
         the second:
 
-        >>> d.decode([0,0,0,0,1,1,1])
-        [0, 7]
+        >>> import numpy as np
+        >>> d.decode(np.array([0,0,0,0,1,1,1]))
+        array([0, 7])
         """
         super().__init__()
         self.descriptors = descriptors
+        self.powers_2 = None
 
     def decode(self, genome, *args, **kwargs):
         """
@@ -51,34 +55,45 @@ class BinaryToIntDecoder(Decoder):
         For example, a Boolean representation of [1, 12, 5] can be decoded
         like this:
 
+        >>> import numpy as np
         >>> d = BinaryToIntDecoder(4, 4, 4)
-        >>> d.decode([0,0,0,1, 1, 1, 0, 0, 0, 1, 1, 0])
-        [1, 12, 6]
+        >>> b = np.array([0,0,0,1, 1, 1, 0, 0, 0, 1, 1, 0])
+        >>> d.decode(b)
+        array([ 1, 12,  6])
         """
+        if not isinstance(genome, np.ndarray):
+            raise ValueError(("Expected genome to be a numpy array. "
+                              f"Got {type(genome)}."))
 
-        # TODO the laborious string conversion approach could be replaced
-        #  with something more elegant; but this was a copy-n-paste job from
-        #  some of my code from elsewhere that I knew worked.
-
-        values = []
+        values = np.zeros(len(self.descriptors), dtype=int)
         offset = 0  # how far are we into the binary test_sequence
 
-        for descriptor in self.descriptors:
+        for i, descriptor in enumerate(self.descriptors):
             # snip out the next test_sequence
             cur_sequence = genome[offset:offset + descriptor]
-            values.append(BinaryToIntDecoder.__binary_to_int(cur_sequence))
+            if self.powers_2 is None or cur_sequence.size > self.powers_2.size:
+                self.powers_2 = 1 << np.arange(cur_sequence.size)[::-1]
+            values[i] = BinaryToIntDecoder.__binary_to_int(
+                cur_sequence, powers_2=self.powers_2)
             offset += descriptor
 
         return values
 
     @staticmethod
-    def __binary_to_int(b):
+    def __binary_to_int(b, powers_2=None):
         """Convert the given binary string to the equivalent
 
-        >>> BinaryToIntDecoder._BinaryToIntDecoder__binary_to_int([0, 1, 0, 1])
+        >>> import numpy as np
+        >>> b = np.array([0, 1, 0, 1])
+        >>> BinaryToIntDecoder._BinaryToIntDecoder__binary_to_int(b)
         5
         """
-        return int(BinaryToIntDecoder.__binary_to_str(b), 2)
+        # compute powers of 2 and cache results
+        if powers_2 is None or b.size > powers_2.size:
+            powers_2 = 1 << np.arange(b.size)[::-1]
+
+        # dot product of bit vector with powers of 2
+        return b.dot(powers_2[-b.size:])
 
     @staticmethod
     def __binary_to_str(b):
@@ -86,7 +101,9 @@ class BinaryToIntDecoder(Decoder):
 
         For example,
 
-        >>> BinaryToIntDecoder._BinaryToIntDecoder__binary_to_str([0,1,0,1])
+        >>> import numpy as np
+        >>> b = np.array([0, 1, 0, 1])
+        >>> BinaryToIntDecoder._BinaryToIntDecoder__binary_to_str(b)
         '0101'
         """
         return "".join([str(x) for x in b])
@@ -127,10 +144,11 @@ class BinaryToRealDecoderCommon(Decoder):
 
         # snip out just the binary segment lengths from the set of tuples;
         # we save this for the subclasses for their binary to integer decoders
-        self.len_segments = list(pluck(0, segments))
+        self.len_segments = np.array(list(pluck(0, segments)))
 
         # how many possible values per segment
-        cardinalities = [2 ** i for i in self.len_segments]
+        # cardinalities = [2 ** i for i in self.len_segments]
+        cardinalities = 1 << self.len_segments
 
         # We will use this function to first decode to integers.
         # This is assigned in the sub-classes depending on whether we want to
@@ -138,21 +156,18 @@ class BinaryToRealDecoderCommon(Decoder):
         self.binary_to_int_decoder = None
 
         # Now get the corresponding real value ranges
-        self.lower_bounds = list(pluck(1, segments))
-        self.upper_bounds = list(pluck(2, segments))
+        self.lower_bounds = np.array(list(pluck(1, segments)))
+        self.upper_bounds = np.array(list(pluck(2, segments)))
 
         # This corresponds to the amount each binary value is multiplied by
         # to get the final real value (plus the lower bound offset, of course)
-        self.increments = [(upper - lower) / (cardinalities - 1) for
-                           lower, upper, cardinalities in
-                           zip(self.lower_bounds, self.upper_bounds,
-                               cardinalities)]
+        self.increments = \
+            (self.upper_bounds - self.lower_bounds) / (cardinalities - 1)
 
     def decode(self, genome, *args, **kwargs):
         """Convert a list of binary values into a real-valued vector."""
         int_values = self.binary_to_int_decoder.decode(genome)
-        values = [l + i * inc for l, i, inc in
-                  zip(self.lower_bounds, int_values, self.increments)]
+        values = self.lower_bounds + (int_values * self.increments)
         return values
 
 
@@ -178,9 +193,10 @@ class BinaryToRealDecoder(BinaryToRealDecoderCommon):
         the second.  The traits have a minimum value of -5.12 (corresponding
         to 0000) and a maximum of 5.12 (corresponding to 1111):
 
+        >>> import numpy as np
         >>> d = BinaryToRealDecoder((4, -5.12, 5.12),(4, -5.12, 5.12))
-        >>> d.decode([0, 0, 0, 0, 1, 1, 1, 1])
-        [-5.12, 5.12]
+        >>> d.decode(np.array([0, 0, 0, 0, 1, 1, 1, 1]))
+        array([-5.12,  5.12])
         """
         super().__init__(*segments)
 
@@ -200,9 +216,11 @@ class BinaryToIntGreyDecoder(BinaryToIntDecoder):
         For example, a grey encoded Boolean representation of [1, 8, 4] can
         be decoded like this:
 
+        >>> import numpy as np
         >>> d = BinaryToIntGreyDecoder(4, 4, 4)
-        >>> d.decode([0,0,0,1, 1, 1, 0, 0, 0, 1, 1, 0])
-        [1, 8, 4]
+        >>> b = np.array([0,0,0,1, 1, 1, 0, 0, 0, 1, 1, 0])
+        >>> d.decode(b)
+        array([1, 8, 4])
     """
 
     def __init__(self, *descriptors):
@@ -229,10 +247,11 @@ class BinaryToIntGreyDecoder(BinaryToIntDecoder):
         # regular binary decoding.
         values = super().decode(genome)
 
+        # TODO: find a way to vectorize using numpy ops
         gray_encoded_values = [BinaryToIntGreyDecoder.__gray_encode(v) for v in
                                values]
 
-        return gray_encoded_values
+        return np.array(gray_encoded_values)
 
 
 ##############################
@@ -255,9 +274,10 @@ class BinaryToRealGreyDecoder(BinaryToRealDecoderCommon):
         traits have a minimum value of -5.12 (corresponding to 0000) and a
         maximum of 5.12 (corresponding to 1111):
 
+        >>> import numpy as np
         >>> d = BinaryToRealGreyDecoder((4, -5.12, 5.12),(4, -5.12, 5.12))
-        >>> d.decode([0, 0, 0, 0, 1, 1, 1, 1])
-        [-5.12, 1.706666666666666]
+        >>> d.decode(np.array([0, 0, 0, 0, 1, 1, 1, 1]))
+        array([-5.12      ,  1.70666667])
         """
         super().__init__(*segments)
 
