@@ -6,6 +6,8 @@ from typing import Iterator, Callable
 import random
 from toolz import curry
 
+import numpy as np
+
 from leap_ec.ops import compute_expected_probability, iteriter_op
 
 
@@ -26,9 +28,10 @@ def apply_mutation(next_individual: Iterator,
 
     >>> from leap_ec.binary_rep.ops import genome_mutate_bitflip
     >>> mutation_op = apply_mutation(mutator=genome_mutate_bitflip)
+    >>> import numpy as np
 
     >>> from leap_ec.individual import Individual
-    >>> original = Individual([[0,0],[1,1]])
+    >>> original = Individual(np.array([[0, 0], [1, 1]]))
     >>> mutated = next(mutation_op(iter([original])))
 
     :param next_individual: to possibly mutate
@@ -78,8 +81,11 @@ def add_segment(next_individual: Iterator,
 
     >>> from leap_ec.individual import Individual
     >>> from leap_ec.binary_rep.initializers import create_binary_sequence
-    >>> original = Individual([[0,0],[1,1]])
-    >>> mutated = next(add_segment(iter([original]), seq_initializer=create_binary_sequence(2), probability=1.0))
+    >>> import numpy as np
+    >>> original = Individual([np.array([0, 0]), np.array([1, 1])])
+    >>> mutated = next(add_segment(iter([original]),
+    ...                seq_initializer=create_binary_sequence(2),
+    ...                probability=1.0))
 
     :param next_individual: to possibly add a segment
     :param seq_initializer: callable for initializing any new segments
@@ -97,7 +103,8 @@ def add_segment(next_individual: Iterator,
                 individual.genome.append(new_segment)
             else:
                 # + 1 to allow for appending new segment
-                insertion_point = random.randrange(len(individual.genome) + 1)
+                insertion_point = random.randrange(
+                    len(individual.genome) + 1)
                 individual.genome.insert(insertion_point, new_segment)
 
             # invalidate the fitness since we have a modified genome
@@ -119,9 +126,11 @@ def remove_segment(next_individual: Iterator,
         no chance for an empty individual to be returned.
 
     >>> from leap_ec.individual import Individual
-    >>> original = Individual([[0,0],[1,1]])
+    >>> import numpy as np
+    >>> original = Individual([np.array([0, 0]), np.array([1, 1])])
     >>> mutated = next(remove_segment(iter([original]), probability=1.0))
-    >>> assert mutated.genome == [[0,0]] or mutated.genome == [[1,1]]
+    >>> assert np.all(mutated.genome[0] == [0, 0]) \
+            or np.all(mutated.genome[0] == [1, 1])
 
         :param next_individual: to have a segment possibly removed
         :param probability: likelihood of removing a segment
@@ -136,7 +145,6 @@ def remove_segment(next_individual: Iterator,
             if random.random() < probability:
                 removed_segment = random.randrange(len(individual.genome))
                 del individual.genome[removed_segment]
-
                 # invalidate the fitness since we have a modified genome
                 individual.fitness = None
 
@@ -154,9 +162,11 @@ def copy_segment(next_individual: Iterator,
     """ with a given probability, randomly select and copy a segment
 
     >>> from leap_ec.individual import Individual
-    >>> original = Individual([[0,0]])
+    >>> import numpy as np
+    >>> original = Individual([np.array([0, 0])])
     >>> mutated = next(copy_segment(iter([original]), probability=1.0))
-    >>> assert mutated.genome == [[0,0],[0,0]]
+    >>> assert np.all(mutated.genome[0] == [0, 0]) \
+           and np.all(mutated.genome[1] == [0, 0])
 
         :param next_individual: to have a segment possibly removed
         :param probability: likelihood of doing this
@@ -171,10 +181,11 @@ def copy_segment(next_individual: Iterator,
                 individual.genome[random.randrange(len(individual.genome))]
 
             if append:
-                individual.genome.insert(len(individual.genome), copied_segment)
+                individual.genome.append(copied_segment)
             else:
                 # + 1 to allow for appending new segment
-                insertion_point = random.randrange(len(individual.genome) + 1)
+                insertion_point = random.randrange(
+                    len(individual.genome) + 1)
                 individual.genome.insert(insertion_point, copied_segment)
 
             # invalidate the fitness since we have a modified genome
